@@ -1,27 +1,26 @@
 require 'spec_helper'
 
 describe 'mistral::api' do
-
   let :params do
-    { :api_workers                     => '1',
+    {
+      :api_workers                     => '1',
       :enabled                         => true,
       :manage_service                  => true,
       :bind_host                       => '127.0.0.1',
       :bind_port                       => '1234',
       :enable_proxy_headers_parsing    => false,
-      :allow_action_execution_deletion => false}
+      :allow_action_execution_deletion => false
+    }
   end
 
   let :pre_condition do
     "class { '::mistral::keystone::authtoken':
-      password => 'foo',
+       password => 'foo',
     }"
   end
 
-  shared_examples_for 'mistral-api' do
-
+  shared_examples 'mistral::api' do
     context 'config params' do
-
       it { is_expected.to contain_class('mistral::params') }
       it { is_expected.to contain_class('mistral::policy') }
       it { is_expected.to contain_class('mistral::keystone::authtoken') }
@@ -43,7 +42,6 @@ describe 'mistral::api' do
         end
 
         it 'configures mistral-api service' do
-
           is_expected.to contain_service('mistral-api').with(
             :ensure     => (params[:manage_service] && params[:enabled]) ? 'running' : 'stopped',
             :name       => platform_params[:api_service_name],
@@ -75,7 +73,6 @@ describe 'mistral::api' do
       end
 
       it 'configures mistral-api service' do
-
         is_expected.to contain_service('mistral-api').with(
           :ensure     => nil,
           :name       => platform_params[:api_service_name],
@@ -117,46 +114,31 @@ describe 'mistral::api' do
         params.merge!({ :service_name => 'foobar' })
       end
 
-      it_raises 'a Puppet::Error', /Invalid service_name/
+      it { should raise_error(Puppet::Error, /Invalid service_name/) }
     end
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily               => 'Debian',
-        :operatingsystem        => 'Debian',
-        :operatingsystemrelease => '8.0',
-        :concat_basedir         => '/var/lib/puppet/concat',
-        :fqdn                   => 'some.host.tld',
-        :os                     => { :name  => 'Debian', :family => 'Debian', :release => { :major => '8', :minor => '0' } },
-      })
-    end
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts({
+          :concat_basedir => '/var/lib/puppet/concat',
+          :fqdn           => 'some.host.tld',
+        }))
+      end
 
-    let :platform_params do
-      { :api_service_name => 'mistral-api' }
-    end
+      let (:platform_params) do
+        case facts[:osfamily]
+        when 'Debian'
+          { :api_service_name => 'mistral-api' }
+        when 'RedHat'
+          { :api_service_name => 'openstack-mistral-api' }
+        end
+      end
 
-    it_configures 'mistral-api'
+      it_behaves_like 'mistral::api'
+    end
   end
-
-  context 'on RedHat platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily               => 'RedHat',
-        :operatingsystem        => 'RedHat',
-        :operatingsystemrelease => '7.1',
-        :fqdn                   => 'some.host.tld',
-        :concat_basedir         => '/var/lib/puppet/concat',
-        :os                     => { :name  => 'RedHat', :family => 'RedHat', :release => { :major => '7', :minor => '1' } },
-      })
-    end
-
-    let :platform_params do
-      { :api_service_name => 'openstack-mistral-api' }
-    end
-
-    it_configures 'mistral-api'
-  end
-
 end
